using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class EvilChickenBehavior : MonoBehaviour
{
    //
    // Constants
    //

    private const float THROW_VELOCITY = 300f;
    private const float MIN_THROW_DELAY = 0.3f;
    private const float MAX_BOMB_PROBABILITY = 0.5f;

    //
    // Reference Objects
    //

    // Template object for beet
    public GameObject beet;

    // Template object for bomb
    public GameObject bomb;
    
    // Origin position to spawn objects
    public Transform origin;

    // Target to throw objects at
    public Transform target;

    //
    // Difficulty Parameters
    //

    // Probability of bomb being thrown
    public float bombProbability = 0.1f;
    
    // Time between throws
    public float throwDelay = 4f;

    // Time between difficulty increases
    public float difficultyIncreaseInterval = 5f;

    // Increase in bomb probability per difficulty increase
    public float bombProbabilityIncrease = 0.02f;

    // Decrease in throw delay per difficulty increase
    public float throwDelayDecrease = 0.2f;

    //
    // Private Time Variables
    //

    // Time (sec) since last object thrown
    private float timeSinceLastThrown = 0;

    // Time (sec) since last difficulty increase
    private float timeSinceLastDifficulty = 0;

    private Vector3 ComputeThrowVector() // USE THIS when adding force to the thrown object
    {
        Vector3 throwDirection = (target.transform.position - transform.position).normalized;
        return throwDirection * THROW_VELOCITY;
    }

    // Update is called once per frame
    void Update()
    {
        timeSinceLastDifficulty += Time.deltaTime;

        if (timeSinceLastDifficulty > difficultyIncreaseInterval)
        {
            timeSinceLastDifficulty = 0;
            throwDelay = Mathf.Max(MIN_THROW_DELAY, throwDelay - throwDelayDecrease);
            bombProbability = Mathf.Min(MAX_BOMB_PROBABILITY, bombProbability + bombProbabilityIncrease);
        }

        // TODO
    }
}
